==> huaweicloudsdkdc-3.1.70-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/create_switchover_test.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateSwitchoverTest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'resource_type': 'str',
        'operation': 'str'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'resource_type': 'resource_type',
        'operation': 'operation'
    }

    def __init__(self, resource_id=None, resource_type=None, operation=None):
        """CreateSwitchoverTest

        The model defined in huaweicloud sdk

        :param resource_id: 倒换测试的资源对象ID
        :type resource_id: str
        :param resource_type: 倒换测试的资源对象类型
        :type resource_type: str
        :param operation: shutdown, undo_shutdown表示倒换测试操作类型
        :type operation: str
        """
        
        

        self._resource_id = None
        self._resource_type = None
        self._operation = None
        self.discriminator = None

        self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        self.operation = operation

    @property
    def resource_id(self):
        """Gets the resource_id of this CreateSwitchoverTest.

        倒换测试的资源对象ID

        :return: The resource_id of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this CreateSwitchoverTest.

        倒换测试的资源对象ID

        :param resource_id: The resource_id of this CreateSwitchoverTest.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """Gets the resource_type of this CreateSwitchoverTest.

        倒换测试的资源对象类型

        :return: The resource_type of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this CreateSwitchoverTest.

        倒换测试的资源对象类型

        :param resource_type: The resource_type of this CreateSwitchoverTest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def operation(self):
        """Gets the operation of this CreateSwitchoverTest.

        shutdown, undo_shutdown表示倒换测试操作类型

        :return: The operation of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this CreateSwitchoverTest.

        shutdown, undo_shutdown表示倒换测试操作类型

        :param operation: The operation of this CreateSwitchoverTest.
        :type operation: str
        """
        self._operation = operation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSwitchoverTest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdc-3.1.143-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/create_switchover_test.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateSwitchoverTest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'resource_type': 'str',
        'operation': 'str'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'resource_type': 'resource_type',
        'operation': 'operation'
    }

    def __init__(self, resource_id=None, resource_type=None, operation=None):
        r"""CreateSwitchoverTest

        The model defined in huaweicloud sdk

        :param resource_id: 倒换测试的资源对象ID
        :type resource_id: str
        :param resource_type: 倒换测试的资源对象类型
        :type resource_type: str
        :param operation: shutdown, undo_shutdown表示倒换测试操作类型
        :type operation: str
        """
        
        

        self._resource_id = None
        self._resource_type = None
        self._operation = None
        self.discriminator = None

        self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        self.operation = operation

    @property
    def resource_id(self):
        r"""Gets the resource_id of this CreateSwitchoverTest.

        倒换测试的资源对象ID

        :return: The resource_id of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        r"""Sets the resource_id of this CreateSwitchoverTest.

        倒换测试的资源对象ID

        :param resource_id: The resource_id of this CreateSwitchoverTest.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        r"""Gets the resource_type of this CreateSwitchoverTest.

        倒换测试的资源对象类型

        :return: The resource_type of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        r"""Sets the resource_type of this CreateSwitchoverTest.

        倒换测试的资源对象类型

        :param resource_type: The resource_type of this CreateSwitchoverTest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def operation(self):
        r"""Gets the operation of this CreateSwitchoverTest.

        shutdown, undo_shutdown表示倒换测试操作类型

        :return: The operation of this CreateSwitchoverTest.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        r"""Sets the operation of this CreateSwitchoverTest.

        shutdown, undo_shutdown表示倒换测试操作类型

        :param operation: The operation of this CreateSwitchoverTest.
        :type operation: str
        """
        self._operation = operation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSwitchoverTest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
